@@ -69,6 +69,10 @@ def is_doctest_active(arg_string: Optional[str] = None) -> bool:
     ----------
     none
 
+    >>> assert False == is_doctest_active(arg_string="")
+    >>> assert True == is_doctest_active(arg_string="docrunner.py")
+    >>> assert True == is_doctest_active(arg_string="doctest.py")
+
     """
     # is_doctest_active}}}
 
@@ -98,6 +102,9 @@ def is_pytest_active(arg_string: Optional[str] = None) -> bool:
     ----------
     none
 
+    >>> assert True == is_pytest_active(arg_string='pytest.py')
+    >>> assert True == is_pytest_active(arg_string='/pytest/__main__.py')
+
     """
     # is_pytest_active}}}
 
@@ -107,7 +114,7 @@ def is_pytest_active(arg_string: Optional[str] = None) -> bool:
         return True
     if ("pytest.py" in arg_string) or ("/pytest/__main__.py" in arg_string):
         return True
-    return False
+    return False            # pragma: no cover
 
 
 # is_setup_active{{{
@@ -130,6 +137,9 @@ def is_setup_active(arg_string: Optional[str] = None) -> bool:
     ----------
     none
 
+    >>> assert False == is_setup_active(arg_string="")
+    >>> assert True == is_setup_active(arg_string="setup.py")
+
     """
     # is_setup_active}}}
     arg_string = _get_sys_argv_str(arg_string)
@@ -156,6 +166,10 @@ def is_setup_test_active(arg_string: Optional[str] = None) -> bool:
     ----------
     none
 
+    >>> assert False == is_setup_test_active('')
+    >>> assert False == is_setup_test_active('setup.py')
+    >>> assert True == is_setup_test_active('setup.py test')
+
     """
     # is_setup_test_active}}}
     arg_string = _get_sys_argv_str(arg_string)
